"""Configuration module for BACore."""

from bacore.domain import info

project_bacore = info.Project(name="BACore",
                              version="0.0.10",
                              description="BACore is a framework for business analysis and test automation.")
